==> haskell-th-utilities-0.2.5.2-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-utilities
version:              0.2.5.2
visibility:           public
id:                   th-utilities-0.2.5.2-Bx3u74A4XyJB2Z8czif41F
key:                  th-utilities-0.2.5.2-Bx3u74A4XyJB2Z8czif41F
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  f40468cd93cfaafd8fca4ee4081e7fa0
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.2-Bx3u74A4XyJB2Z8czif41F
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    primitive-0.9.1.0-7Mxe299pqmeEMzCjDfyLk3
    syb-0.7.3-3SVfrNQz4RF9JrEUNzpzyO template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-orphans-0.13.16-3i3zvtqzbfpIR8Br44gMeo

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.5.2-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-utilities
version:              0.2.5.2
visibility:           public
id:                   th-utilities-0.2.5.2-7z4CoLzEPBlLnaGHLqVITg
key:                  th-utilities-0.2.5.2-7z4CoLzEPBlLnaGHLqVITg
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  8d9270a27d153b2d8978153fbbc7fe3d
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.2-7z4CoLzEPBlLnaGHLqVITg
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    primitive-0.9.1.0-8f7NBHiHFdgFE3qTf44BEn
    syb-0.7.3-Dk2TUQSTxWd5yTqOEWpD7k template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-orphans-0.13.16-9Ws7zClcguv2rf6o5mkz2

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
